#_____________________________________________________________________________________
#
# Exempelkod för att hämta data från statistikdabasen (statistik.konj.se)
# Example code for fetching data from the forecast database (statistik.konj.se)
#
# Du behöver installera pyjstat, skriv följande i kommandotolken
# You need to install pyjstat, in the command prompt write the following
#
# py -m pip install pyjstat
#_____________________________________________________________________________________

#_____________________________________________________________________________________

# Importera paket
# Import package
from pyjstat import pyjstat
import requests
from matplotlib import pyplot as plt
import pandas as pd

#_____________________________________________________________________________________

# Hämta månadsdata för hela perioden för variabeln Barometerindikatorn, efter att en tabell har genererats
# från databasen, är URL:en och den faktiska JSON-förfrågan belägna längst ner

# Fetch monthly data for the entire period for the variable Barometerindicator, after a table has been generated
# from the database, the URL and the actual JSON query are located at the bottom.

# Ange URL:en
# Input the URL
POST_URL = 'https://statistik.konj.se:443/PxWeb/api/v1/sv/KonjBar/indikatorer/Indikatorm.px'

# Ange JSON-förfrågan
# Input the JSON query
payload = {
  "query": [
    {
      "code": "Indikator",
      "selection": {
        "filter": "item",
        "values": [
          "KIFI"
        ]
      }
    }
  ],
  "response": {
     # Observera att 'format':'px' har ändrats till JSON-stat
     # Note that 'format':'px' has been changed to JSON-stat
     "format": "json-stat"
  }
}

#_____________________________________________________________________________________

# Ladda data
# Load data

response = requests.post(POST_URL,json = payload)
print(response)

dataset = pyjstat.Dataset.read(response.text)
df = dataset.write('dataframe')
print(df.head())

# _____________________________________________________________________________________

# Skapa graf
# Create graph

# Ändra formatet på perioden
# Change the format of the period

df["Period"] = pd.to_datetime(df["Period"], format = "%YM%m")
df.set_index("Period",inplace=True)

# Skapa graf
# Create graph
plt.figure(figsize = (8,6),dpi=100)
plt.plot(df[["value"]])
plt.grid(axis = 'y', color = "lightgrey", alpha=0.3)

# Lägg till titel och visa diagramet
# Add title and show the graph
plt.title("Barometerindikatorn, 1996-2024, \n" "månatlig frekvens")
plt.show()
